.. Copyright 2013 Matthew Henderson
   Created Sat Sep 14 18:01:51 BST 2013. Last updated Sat Sep 14 18:08:35 BST 2013.

Installation
============

Requirements
------------

Ryser needs:

* NetworkX (http://networkx.github.io/) 
* Vizing (http://pythonhosted.org/vizing/)

Download
--------

The latest Ryser distribution can be downloaded from PyPi (https://pypi.python.org/pypi/ryser/)

Installation Instructions
-------------------------

The recommended way to install Ryser is with pip (http://www.pip-installer.org/en/latest/)

..  code:: bash

    $ pip install ryser

